package webclient;
import java.net.CookieStore;
import java.net.HttpCookie;
import java.net.URI;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;

public class MyCookieStore implements CookieStore {
    // Map for storing cookies
    private Map<URI, List<HttpCookie>> map = 
            new HashMap<URI, List<HttpCookie>>();
    
    // Add cookie
    public void add(URI uri, HttpCookie cookie) {
        System.out.println("Add cookie for " + uri + ": " 
                + cookie);
        List<HttpCookie> cookies = map.get(uri);
        if (cookies == null) {
            cookies = new ArrayList<HttpCookie>();
            map.put(uri, cookies);
        }
        cookies.add(cookie);
    }

    // get Cookie
    public List<HttpCookie> get(URI uri) {
        List<HttpCookie> cookies = map.get(uri);
        if (cookies == null) {
            cookies = new ArrayList<HttpCookie>();
            map.put(uri, cookies);
        }
        System.out.println("Get cookies for " + uri + ": " 
                + cookies);
        return cookies;
    }

    // Get all cookies
    public List<HttpCookie> getCookies() {
        Collection<List<HttpCookie>> values = map.values();
        List<HttpCookie> result = new ArrayList<HttpCookie>();
        for (List<HttpCookie> value : values) {
            result.addAll(value);
        }
        return result;
    }

    // Get all registered URIs
    public List<URI> getURIs() {
        Set<URI> keys = map.keySet();
        return new ArrayList<URI>(keys);
    }

    // Delete the specified cookie
    public boolean remove(URI uri, HttpCookie cookie) {
        List<HttpCookie> cookies = map.get(uri);
        if (cookies == null) {
            return false;
        }
        return cookies.remove(cookie);
    }

    // Remove all cookies
    public boolean removeAll() {
        map.clear();
        return true;
    }
}
